/*
 * gc global variable provides access to GUI Composer infrastructure components and project information.
 * For more information, please see the Working with Javascript guide in the online help.
 */
var gc = gc || {};
gc.services = gc.services || {};

/*
 *  Boilerplate code for creating computed data bindings
 */
document.addEventListener('gc-databind-ready', function() {
    /* 
     *   Add custom computed value databindings here, using the following method:
     *
     *   function gc.databind.registry.bind(targetBinding, modelBinding, [getter], [setter]);
     *
     *   param targetBinding - single binding string or expression, or array of binding strings for multi-way binding.
     *   param modelBinding - single binding string or expression, or array of binding strings for multi-way binding.
     *   param getter - (optional) - custom getter function for computing the targetBinding value(s) based on modelBinding value(s).
     *   param setter - (optional) - custom setter function for computing the modelBinding value(s) based on targetBinding value(s).
     */

    // For example, a simple computed values based on simple expression
    // gc.databind.registry.bind('widget.id.propertyName', "targetVariable == 1 ? 'binding is one' : 'binding is not one'");

    // Or a custom two-way binding with custome getter and setter functions.  (setter is optional)  (getter only indicates one-way binding)
    // gc.databind.registry.bind('widget.id.propertyName', "targetVariable", function(value) { return value*5/9 + 32; }, function(value) { (return value-32)*9/5; });

    // Event 1 to n bindings
    /* 
    gc.databind.registry.bind('widget.date.value', 
        // dependant bindings needed in order to compute the date, in name/value pairs.
        {
            weekday: 'widget.dayOfWeek.selectedText',
            day: 'widget.dayOfMonth.value',
            month: 'widget.month.selectedText',
            year: 'widget.year.value'
        }, 
        // getter for date computation
        function(values) 
        {
            // compute and return the string value to bind to the widget with id 'date'
            return values.weekday + ', ' + values.month + ' ' + values.day + ', ' + values.year;
        }
    ); 
	*/
});

/*
 *  Boilerplate code for creating custom actions
 */
document.addEventListener('gc-nav-ready', function() {
    /* 
     *   Add custom actions for menu items using the following api:
     *
     *   function gc.nav.registryAction(id, runable, [isAvailable], [isVisible]);
     *
     *   param id - uniquely identifies the action, and should correspond to the action property of the menuaction widget.
     *   param runable - function that performs the custom action.
     *   param isAvailable - (optional) - function called when the menu action is about to appear.  Return false to disable the action, or true to enable it.
     *   param isVisible - (optional) - function called when the menu action is about to appear.  Return false to hide the action, or true to make it visible.
     */

    // For example,
    // gc.nav.registerAction('myCustomCloseAction', function() { window.close(); }, function() { return true; }, function() { return true; });

    // Alternatively, to programmatically disable a menu action at any time use:
    // gc.nav.disableAction('myCustomCloseAction);    then enable it again using:  gc.nav.enableAction('myCustomCloseAction'); 
});

/*
 *  Boilerplate code for working with components in the application gist
 */


var initComplete = false;
var templateObj;

// Wait for DOMContentLoaded event before trying to access the application template
var init = function() {
    templateObj = document.querySelector('#template_obj');

    // Wait for the template to fire a dom-change event to indicate that it has been 'stamped'
    // before trying to access components in the application.
    templateObj.addEventListener('dom-change', function() {
        if (initComplete) return;
        this.async(function() {
            initComplete = true;
            console.log("Application template has been stamped.");
            // Now that the template has been stamped, you can use 'automatic node finding' $ syntax to access widgets.
            // e.g. to access a widget with an id of 'widget_id' you can use templateObj.$.widgetId


            var line0 = {
                x: [0],
                y: [0],
                mode: 'lines',
                color: 'red',
                name: 'line0'
            };
            var line1 = {
                x: [0],
                y: [0],
                mode: 'lines',
                color: 'orange',
                name: 'line1'
            };
    
            var line2 = {
                x: [0],
                y: [2],
                mode: 'lines',
                color: 'aqua'
            };
            var line3= {
                x: [0],
                y: [3],
                mode: 'lines',
                color: 'blue'
            };
            var line4 = {
                x: [0],
                y: [4],
                mode: 'lines',
                color: 'teal'
            };
            var line5 = {
                x: [0],
                y: [5],
                mode: 'lines',
                color: 'lime'
                
            };
            var line6 = {
                x: [0],
                y: [6],
                mode: 'lines',
                color: 'purple'
            };
            var line7 = {
                x: [0],
                y: [7],
                mode: 'lines',
                color: 'magenta'
            };
            var line8 = {
                x: [0],
                y: [8],
                mode: 'lines',
                color: 'black'
            };
            var line9 = {
                x: [0],
                y: [9],
                mode: 'lines',
                color: 'grey'
                
            };
            var line10 = {
                x: [0],
                y: [10],
                mode: 'lines',
                color: 'blueViolet'
            };
            var line11 = {
                x: [0],
                y: [11],
                mode: 'lines',
                color: 'aquamarine'
            };
            var line12 = {
                x: [0],
                y: [12],
                mode: 'lines',
                color: 'brown'
            };
            var line13 = {
                x: [0],
                y: [13],
                mode: 'lines',
                color: 'cyan'
                
            };
            var line14 = {
                x: [0],
                y: [14],
                mode: 'lines',
                color: 'DarkOrange'
            };
            
            var line15 = {
                x: [0],
                y: [0],
                mode: 'lines',
                color: 'DeepPink'
            };
            
            templateObj.$.ti_widget_plot.data = [line0,line1,line2,line3,line4,line5,line6,line7,line8,line9,line10,line11,line12,line13,line14,line15];
            templateObj.$.ti_widget_plot.layout = {
                margin: {
                    t: 0
                }
            };
            var sliderVal = templateObj.$.ti_widget_slider.value;
            templateObj.$.ti_widget_slider.addEventListener("changed",function(event) {
                sliderVal = event.detail.newValue;
            });
            templateObj.$.ti_widget_slider.value = 3;
            templateObj.$.ti_widget_plot.config = config = {
                'linkText': "name of graph",
                'scrollZoom': true,
                'displayModeBar': true,
                'editable': true
            };
            templateObj.$.ti_widget_plot.redraw();
            var cnt = 0;

            var interval = setInterval(function() {
                cnt++;
                var update = {
                    x: [[cnt],[cnt],[cnt],[cnt],[cnt],[cnt],[cnt],[cnt],[cnt],[cnt],[cnt],[cnt],[cnt],[cnt],[cnt],[cnt]],
                    y: [[sliderVal],[sliderVal*2],[sliderVal-2.2],[sliderVal-1.8],[sliderVal-1.5],[sliderVal-1.2],[sliderVal-0.9],[sliderVal-0.7],
                        [sliderVal-0.5],[sliderVal-0.2],[sliderVal+0.2],[sliderVal+0.5],[sliderVal+0.7],[sliderVal+0.9],[sliderVal+1.2],[sliderVal*0.4]]
                }
                if (templateObj.$.ti_widget_checkbox_random.checked) {
                    update.y = [];
                    for (var i=0; i < 16; i++) {
                        update.y.push([Math.random() * 3 * sliderVal]);
                    }
                }

                Plotly.extendTraces(templateObj.$.ti_widget_plot.$.plot, update, [0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15])
            },1000);
        }, 1);

    });
};

templateObj = document.querySelector('#template_obj');
if (templateObj) {
    init();
} else {
    document.addEventListener('DOMContentLoaded', init.bind(this))
}